@@ -1245,8 +1245,8 @@ None by default.
   void EndShaderMode(void)
   void EndTextureMode(void)
   void EndVrDrawing(void)
-  void ExportImage(char *fileName, Image image)
-  void ExportMesh(char *fileName, Mesh mesh)
+  void ExportImage(Image image, char *fileName)
+  void ExportMesh(Mesh mesh, char *fileName)
   Color Fade(Color color, float alpha)
   char *FormatText(char *text, ...)
   Image GenImageCellular(int width, int height, int tileSize)
